@@ -38,6 +38,9 @@
 #define GLhandleARB GLuint
 #endif
 
+#define GST_GL_SHADER_GET_PRIVATE(o)					\
+  (G_TYPE_INSTANCE_GET_PRIVATE((o), GST_TYPE_GL_SHADER, GstGLShaderPrivate))
+
 #define USING_OPENGL(context) (gst_gl_context_check_gl_version (context, GST_GL_API_OPENGL, 1, 0))
 #define USING_OPENGL3(context) (gst_gl_context_check_gl_version (context, GST_GL_API_OPENGL3, 3, 1))
 #define USING_GLES(context) (gst_gl_context_check_gl_version (context, GST_GL_API_GLES, 1, 0))
@@ -88,7 +91,7 @@ GST_DEBUG_CATEGORY_STATIC (gst_gl_shader_debug);
 #define DEBUG_INIT \
   GST_DEBUG_CATEGORY_INIT (gst_gl_shader_debug, "glshader", 0, "shader");
 G_DEFINE_TYPE_WITH_CODE (GstGLShader, gst_gl_shader, GST_TYPE_OBJECT,
-    G_ADD_PRIVATE (GstGLShader) DEBUG_INIT);
+    DEBUG_INIT);
 
 static void
 _cleanup_shader (GstGLContext * context, GstGLShader * shader)
@@ -171,6 +174,8 @@ gst_gl_shader_class_init (GstGLShaderClass * klass)
   /* bind class methods .. */
   GObjectClass *obj_class = G_OBJECT_CLASS (klass);
 
+  g_type_class_add_private (klass, sizeof (GstGLShaderPrivate));
+
   obj_class->finalize = gst_gl_shader_finalize;
   obj_class->set_property = gst_gl_shader_set_property;
   obj_class->get_property = gst_gl_shader_get_property;
@@ -190,7 +195,7 @@ gst_gl_shader_init (GstGLShader * self)
   /* initialize sources and create program object */
   GstGLShaderPrivate *priv;
 
-  priv = self->priv = gst_gl_shader_get_instance_private (self);
+  priv = self->priv = GST_GL_SHADER_GET_PRIVATE (self);
 
   priv->linked = FALSE;
   priv->uniform_locations =
@@ -216,9 +221,6 @@ _get_uniform_location (GstGLShader * shader, const gchar * name)
     location = GPOINTER_TO_INT (value);
   }
 
-  GST_TRACE_OBJECT (shader, "Retrieved uniform \'%s\' location %i", name,
-      location);
-
   return location;
 }
 
@@ -438,7 +440,7 @@ gst_gl_shader_detach_unlocked (GstGLShader * shader, GstGLSLStage * stage)
   g_return_if_fail (GST_IS_GLSL_STAGE (stage));
 
   if (!_gst_glsl_funcs_fill (&shader->priv->vtable, shader->context)) {
-    GST_WARNING_OBJECT (shader, "Failed to retrieve required GLSL functions");
+    GST_WARNING_OBJECT (shader, "Failed to retreive required GLSL functions");
     return;
   }
 
@@ -459,8 +461,8 @@ gst_gl_shader_detach_unlocked (GstGLShader * shader, GstGLSLStage * stage)
   }
 
   if (shader->context->gl_vtable->IsProgram)
-    g_assert (shader->context->gl_vtable->IsProgram (shader->
-            priv->program_handle));
+    g_assert (shader->context->gl_vtable->IsProgram (shader->priv->
+            program_handle));
   if (shader->context->gl_vtable->IsShader)
     g_assert (shader->context->gl_vtable->IsShader (stage_handle));
 
@@ -519,7 +521,7 @@ gst_gl_shader_attach_unlocked (GstGLShader * shader, GstGLSLStage * stage)
   g_return_val_if_fail (GST_IS_GLSL_STAGE (stage), FALSE);
 
   if (!_gst_glsl_funcs_fill (&shader->priv->vtable, shader->context)) {
-    GST_WARNING_OBJECT (shader, "Failed to retrieve required GLSL functions");
+    GST_WARNING_OBJECT (shader, "Failed to retreive required GLSL functions");
     gst_object_ref_sink (stage);
     gst_object_unref (stage);
     return FALSE;
@@ -546,8 +548,8 @@ gst_gl_shader_attach_unlocked (GstGLShader * shader, GstGLSLStage * stage)
   }
 
   if (shader->context->gl_vtable->IsProgram)
-    g_assert (shader->context->gl_vtable->IsProgram (shader->
-            priv->program_handle));
+    g_assert (shader->context->gl_vtable->IsProgram (shader->priv->
+            program_handle));
   if (shader->context->gl_vtable->IsShader)
     g_assert (shader->context->gl_vtable->IsShader (stage_handle));
 
@@ -661,7 +663,7 @@ gst_gl_shader_link (GstGLShader * shader, GError ** error)
 
   if (!_gst_glsl_funcs_fill (&shader->priv->vtable, shader->context)) {
     g_set_error (error, GST_GLSL_ERROR, GST_GLSL_ERROR_PROGRAM,
-        "Failed to retrieve required GLSL functions");
+        "Failed to retreive required GLSL functions");
     GST_OBJECT_UNLOCK (shader);
     return FALSE;
   }
@@ -710,7 +712,7 @@ gst_gl_shader_link (GstGLShader * shader, GError ** error)
     GST_OBJECT_UNLOCK (shader);
     return ret;
   } else if (len > 1) {
-    GST_FIXME ("shader link log:\n%s", info_buffer);
+    GST_FIXME ("shader link log:\n%s\n", info_buffer);
   }
 
   ret = priv->linked = TRUE;
@@ -825,51 +827,32 @@ gst_gl_context_clear_shader (GstGLContext * context)
     gl->UseProgramObject (0);
 }
 
-#define set_uniform_pre_check(shader, name)                                 \
-  GLint location = -1;                                                      \
-  g_return_if_fail (shader != NULL);                                        \
-  g_return_if_fail (shader->priv->program_handle != 0);                     \
-  location = _get_uniform_location (shader, name);
-
-#define set_uniform_v(gl_suffix, c_type, debug_stride, debug_str, ...)      \
-void \
-G_PASTE(gst_gl_shader_set_uniform_,gl_suffix) (GstGLShader * shader,        \
-        const gchar * name, guint count, const c_type * value)              \
-{                                                                           \
-  guint i;                                                                  \
-  set_uniform_pre_check(shader, name)                                       \
-  for (i = 0; i < count; i++) {                                             \
-    const c_type * item = &value[i * debug_stride];                         \
-    GST_TRACE_OBJECT (shader, "Setting uniform %s (%i) index %i to "        \
-        debug_str, name, location, i, __VA_ARGS__);                         \
-  }                                                                         \
-  shader->context->gl_vtable->G_PASTE(Uniform,gl_suffix) (location, count, value); \
-}
-
-#define set_uniform_func_decl(gl_suffix, ...)                               \
-void                                                                        \
-G_PASTE(gst_gl_shader_set_uniform_,gl_suffix) (GstGLShader * shader,        \
-    const gchar * name, __VA_ARGS__)
-
-#define set_uniform_body(gl_suffix, debug_str, ...)                         \
-{                                                                           \
-  set_uniform_pre_check(shader, name)                                       \
-  GST_TRACE_OBJECT (shader, "Setting uniform %s (%i) = " debug_str,         \
-      name, location, __VA_ARGS__);                                         \
-  shader->context->gl_vtable->G_PASTE(Uniform,gl_suffix) (location, __VA_ARGS__); \
-}
-
-/* *INDENT-OFF* */
 /**
  * gst_gl_shader_set_uniform_1f:
  * @shader: a #GstGLShader
  * @name: name of the uniform
  * @value: value to set
  *
- * Perform `glUniform1f()` for @name on @shader
+ * Perform glUniform1f() for @name on @shader
  */
-set_uniform_func_decl(1f, float value)
-set_uniform_body(1f, "%f", value);
+void
+gst_gl_shader_set_uniform_1f (GstGLShader * shader, const gchar * name,
+    gfloat value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform1f (location, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_1fv:
@@ -878,9 +861,25 @@ set_uniform_body(1f, "%f", value);
  * @count: number of values to set
  * @value: (array length=count): values to set
  *
- * Perform `glUniform1fv()` for @name on @shader
+ * Perform glUniform1fv() for @name on @shader
  */
-set_uniform_v(1fv, float, 1, "%f", item[0]);
+void
+gst_gl_shader_set_uniform_1fv (GstGLShader * shader, const gchar * name,
+    guint count, const gfloat * value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform1fv (location, count, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_1i:
@@ -888,10 +887,25 @@ set_uniform_v(1fv, float, 1, "%f", item[0]);
  * @name: name of the uniform
  * @value: value to set
  *
- * Perform `glUniform1i()` for @name on @shader
+ * Perform glUniform1i() for @name on @shader
  */
-set_uniform_func_decl(1i, int value)
-set_uniform_body(1i, "%i", value);
+void
+gst_gl_shader_set_uniform_1i (GstGLShader * shader, const gchar * name,
+    gint value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform1i (location, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_1iv:
@@ -900,9 +914,25 @@ set_uniform_body(1i, "%i", value);
  * @count: number of values to set
  * @value: (array length=count): values to set
  *
- * Perform `glUniform1iv()` for @name on @shader
+ * Perform glUniform1iv() for @name on @shader
  */
-set_uniform_v(1iv, int, 1, "%i", item[0]);
+void
+gst_gl_shader_set_uniform_1iv (GstGLShader * shader, const gchar * name,
+    guint count, const gint * value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform1iv (location, count, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_2f:
@@ -911,10 +941,25 @@ set_uniform_v(1iv, int, 1, "%i", item[0]);
  * @v0: first value to set
  * @v1: second value to set
  *
- * Perform `glUniform2f()` for @name on @shader
+ * Perform glUniform2f() for @name on @shader
  */
-set_uniform_func_decl(2f, float v0, float v1)
-set_uniform_body(2f, "%f, %f", v0, v1);
+void
+gst_gl_shader_set_uniform_2f (GstGLShader * shader, const gchar * name,
+    gfloat v0, gfloat v1)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform2f (location, v0, v1);
+}
 
 /**
  * gst_gl_shader_set_uniform_2fv:
@@ -923,9 +968,25 @@ set_uniform_body(2f, "%f, %f", v0, v1);
  * @count: number of values to set
  * @value: (array length=count): values to set
  *
- * Perform `glUniform2fv()` for @name on @shader
+ * Perform glUniform2fv() for @name on @shader
  */
-set_uniform_v(2fv, float, 2, "%f, %f", item[0], item[1]);
+void
+gst_gl_shader_set_uniform_2fv (GstGLShader * shader, const gchar * name,
+    guint count, const gfloat * value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform2fv (location, count, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_2i:
@@ -934,10 +995,25 @@ set_uniform_v(2fv, float, 2, "%f, %f", item[0], item[1]);
  * @v0: first value to set
  * @v1: second value to set
  *
- * Perform `glUniform2i()` for @name on @shader
+ * Perform glUniform2i() for @name on @shader
  */
-set_uniform_func_decl(2i, int v0, int v1)
-set_uniform_body(2i, "%i, %i", v0, v1);
+void
+gst_gl_shader_set_uniform_2i (GstGLShader * shader, const gchar * name,
+    gint v0, gint v1)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform2i (location, v0, v1);
+}
 
 /**
  * gst_gl_shader_set_uniform_2iv:
@@ -946,9 +1022,25 @@ set_uniform_body(2i, "%i, %i", v0, v1);
  * @count: number of values to set
  * @value: (array length=count): values to set
  *
- * Perform `glUniform2iv()` for @name on @shader
+ * Perform glUniform2iv() for @name on @shader
  */
-set_uniform_v(2iv, int, 2, "%i, %i", item[0], item[1]);
+void
+gst_gl_shader_set_uniform_2iv (GstGLShader * shader, const gchar * name,
+    guint count, const gint * value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform2iv (location, count, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_3f:
@@ -958,10 +1050,25 @@ set_uniform_v(2iv, int, 2, "%i, %i", item[0], item[1]);
  * @v1: second value to set
  * @v2: third value to set
  *
- * Perform `glUniform3f()` for @name on @shader
+ * Perform glUniform3f() for @name on @shader
  */
-set_uniform_func_decl(3f, float v0, float v1, float v2)
-set_uniform_body(3f, "%f, %f, %f", v0, v1, v2);
+void
+gst_gl_shader_set_uniform_3f (GstGLShader * shader, const gchar * name,
+    gfloat v0, gfloat v1, gfloat v2)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform3f (location, v0, v1, v2);
+}
 
 /**
  * gst_gl_shader_set_uniform_3fv:
@@ -970,9 +1077,25 @@ set_uniform_body(3f, "%f, %f, %f", v0, v1, v2);
  * @count: number of values to set
  * @value: (array length=count): values to set
  *
- * Perform `glUniform3fv()` for @name on @shader
+ * Perform glUniform3fv() for @name on @shader
  */
-set_uniform_v(3fv, float, 3, "%f, %f, %f", item[0], item[1], item[2]);
+void
+gst_gl_shader_set_uniform_3fv (GstGLShader * shader, const gchar * name,
+    guint count, const gfloat * value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform3fv (location, count, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_3i:
@@ -982,10 +1105,25 @@ set_uniform_v(3fv, float, 3, "%f, %f, %f", item[0], item[1], item[2]);
  * @v1: second value to set
  * @v2: third value to set
  *
- * Perform `glUniform3i()` for @name on @shader
+ * Perform glUniform3i() for @name on @shader
  */
-set_uniform_func_decl(3i, int v0, int v1, int v2)
-set_uniform_body(3i, "%i, %i, %i", v0, v1, v2);
+void
+gst_gl_shader_set_uniform_3i (GstGLShader * shader, const gchar * name,
+    gint v0, gint v1, gint v2)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform3i (location, v0, v1, v2);
+}
 
 /**
  * gst_gl_shader_set_uniform_3iv:
@@ -994,9 +1132,25 @@ set_uniform_body(3i, "%i, %i, %i", v0, v1, v2);
  * @count: number of values to set
  * @value: (array length=count): values to set
  *
- * Perform `glUniform3iv()` for @name on @shader
+ * Perform glUniform3iv() for @name on @shader
  */
-set_uniform_v(3iv, int, 3, "%i, %i, %i", item[0], item[1], item[2]);
+void
+gst_gl_shader_set_uniform_3iv (GstGLShader * shader, const gchar * name,
+    guint count, const gint * value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform3iv (location, count, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_4f:
@@ -1007,10 +1161,25 @@ set_uniform_v(3iv, int, 3, "%i, %i, %i", item[0], item[1], item[2]);
  * @v2: third value to set
  * @v3: fourth value to set
  *
- * Perform `glUniform4f()` for @name on @shader
+ * Perform glUniform4f() for @name on @shader
  */
-set_uniform_func_decl(4f, float v0, float v1, float v2, float v3)
-set_uniform_body(4f, "%f, %f, %f, %f", v0, v1, v2, v3);
+void
+gst_gl_shader_set_uniform_4f (GstGLShader * shader, const gchar * name,
+    gfloat v0, gfloat v1, gfloat v2, gfloat v3)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform4f (location, v0, v1, v2, v3);
+}
 
 /**
  * gst_gl_shader_set_uniform_4fv:
@@ -1019,9 +1188,25 @@ set_uniform_body(4f, "%f, %f, %f, %f", v0, v1, v2, v3);
  * @count: number of values to set
  * @value: (array length=count): values to set
  *
- * Perform `glUniform4fv()` for @name on @shader
+ * Perform glUniform4fv() for @name on @shader
  */
-set_uniform_v(4fv, float, 4, "%f, %f, %f, %f", item[0], item[1], item[2], item[3]);
+void
+gst_gl_shader_set_uniform_4fv (GstGLShader * shader, const gchar * name,
+    guint count, const gfloat * value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform4fv (location, count, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_4i:
@@ -1032,10 +1217,25 @@ set_uniform_v(4fv, float, 4, "%f, %f, %f, %f", item[0], item[1], item[2], item[3
  * @v2: third value to set
  * @v3: fourth value to set
  *
- * Perform `glUniform4i()` for @name on @shader
+ * Perform glUniform4i() for @name on @shader
  */
-set_uniform_func_decl(4i, int v0, int v1, int v2, int v3)
-set_uniform_body(4i, "%i, %i, %i, %i", v0, v1, v2, v3);
+void
+gst_gl_shader_set_uniform_4i (GstGLShader * shader, const gchar * name,
+    gint v0, gint v1, gint v2, gint v3)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform4i (location, v0, v1, v2, v3);
+}
 
 /**
  * gst_gl_shader_set_uniform_4iv:
@@ -1044,10 +1244,25 @@ set_uniform_body(4i, "%i, %i, %i, %i", v0, v1, v2, v3);
  * @count: number of values to set
  * @value: (array length=count): values to set
  *
- * Perform `glUniform4iv()` for @name on @shader
+ * Perform glUniform4iv() for @name on @shader
  */
-set_uniform_v(4iv, int, 4, "%i, %i, %i, %i", item[0], item[1], item[2], item[3]);
-/* *INDENT-ON* */
+void
+gst_gl_shader_set_uniform_4iv (GstGLShader * shader, const gchar * name,
+    guint count, const gint * value)
+{
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->Uniform4iv (location, count, value);
+}
 
 /**
  * gst_gl_shader_set_uniform_matrix_2fv:
@@ -1057,15 +1272,24 @@ set_uniform_v(4iv, int, 4, "%i, %i, %i, %i", item[0], item[1], item[2], item[3])
  * @transpose: transpose the matrix
  * @value: matrix to set
  *
- * Perform `glUniformMatrix2fv()` for @name on @shader
+ * Perform glUniformMatrix2fv() for @name on @shader
  */
 void
 gst_gl_shader_set_uniform_matrix_2fv (GstGLShader * shader, const gchar * name,
     gint count, gboolean transpose, const gfloat * value)
 {
-  set_uniform_pre_check (shader, name);
-  shader->context->gl_vtable->UniformMatrix2fv (location, count, transpose,
-      value);
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->UniformMatrix2fv (location, count, transpose, value);
 }
 
 /**
@@ -1076,15 +1300,24 @@ gst_gl_shader_set_uniform_matrix_2fv (GstGLShader * shader, const gchar * name,
  * @transpose: transpose the matrix
  * @value: values to set
  *
- * Perform `glUniformMatrix3fv()` for @name on @shader
+ * Perform glUniformMatrix3fv() for @name on @shader
  */
 void
 gst_gl_shader_set_uniform_matrix_3fv (GstGLShader * shader, const gchar * name,
     gint count, gboolean transpose, const gfloat * value)
 {
-  set_uniform_pre_check (shader, name);
-  shader->context->gl_vtable->UniformMatrix3fv (location, count, transpose,
-      value);
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->UniformMatrix3fv (location, count, transpose, value);
 }
 
 /**
@@ -1095,15 +1328,24 @@ gst_gl_shader_set_uniform_matrix_3fv (GstGLShader * shader, const gchar * name,
  * @transpose: transpose the matrix
  * @value: values to set
  *
- * Perform `glUniformMatrix4fv()` for @name on @shader
+ * Perform glUniformMatrix4fv() for @name on @shader
  */
 void
 gst_gl_shader_set_uniform_matrix_4fv (GstGLShader * shader, const gchar * name,
     gint count, gboolean transpose, const gfloat * value)
 {
-  set_uniform_pre_check (shader, name);
-  shader->context->gl_vtable->UniformMatrix4fv (location, count, transpose,
-      value);
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->UniformMatrix4fv (location, count, transpose, value);
 }
 
 /**
@@ -1114,15 +1356,24 @@ gst_gl_shader_set_uniform_matrix_4fv (GstGLShader * shader, const gchar * name,
  * @transpose: transpose the matrix
  * @value: values to set
  *
- * Perform `glUniformMatrix2x3fv()` for @name on @shader
+ * Perform glUniformMatrix2x3fv() for @name on @shader
  */
 void
 gst_gl_shader_set_uniform_matrix_2x3fv (GstGLShader * shader,
     const gchar * name, gint count, gboolean transpose, const gfloat * value)
 {
-  set_uniform_pre_check (shader, name);
-  shader->context->gl_vtable->UniformMatrix2x3fv (location, count, transpose,
-      value);
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->UniformMatrix2x3fv (location, count, transpose, value);
 }
 
 /**
@@ -1133,15 +1384,24 @@ gst_gl_shader_set_uniform_matrix_2x3fv (GstGLShader * shader,
  * @transpose: transpose the matrix
  * @value: values to set
  *
- * Perform `glUniformMatrix2x4fv()` for @name on @shader
+ * Perform glUniformMatrix2x4fv() for @name on @shader
  */
 void
 gst_gl_shader_set_uniform_matrix_2x4fv (GstGLShader * shader,
     const gchar * name, gint count, gboolean transpose, const gfloat * value)
 {
-  set_uniform_pre_check (shader, name);
-  shader->context->gl_vtable->UniformMatrix2x4fv (location, count, transpose,
-      value);
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->UniformMatrix2x4fv (location, count, transpose, value);
 }
 
 /**
@@ -1152,15 +1412,24 @@ gst_gl_shader_set_uniform_matrix_2x4fv (GstGLShader * shader,
  * @transpose: transpose the matrix
  * @value: values to set
  *
- * Perform `glUniformMatrix3x2fv()` for @name on @shader
+ * Perform glUniformMatrix3x2fv() for @name on @shader
  */
 void
 gst_gl_shader_set_uniform_matrix_3x2fv (GstGLShader * shader,
     const gchar * name, gint count, gboolean transpose, const gfloat * value)
 {
-  set_uniform_pre_check (shader, name);
-  shader->context->gl_vtable->UniformMatrix3x2fv (location, count, transpose,
-      value);
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->UniformMatrix3x2fv (location, count, transpose, value);
 }
 
 /**
@@ -1171,15 +1440,24 @@ gst_gl_shader_set_uniform_matrix_3x2fv (GstGLShader * shader,
  * @transpose: transpose the matrix
  * @value: values to set
  *
- * Perform `glUniformMatrix3x4fv()` for @name on @shader
+ * Perform glUniformMatrix3x4fv() for @name on @shader
  */
 void
 gst_gl_shader_set_uniform_matrix_3x4fv (GstGLShader * shader,
     const gchar * name, gint count, gboolean transpose, const gfloat * value)
 {
-  set_uniform_pre_check (shader, name);
-  shader->context->gl_vtable->UniformMatrix3x4fv (location, count, transpose,
-      value);
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->UniformMatrix3x4fv (location, count, transpose, value);
 }
 
 /**
@@ -1190,15 +1468,24 @@ gst_gl_shader_set_uniform_matrix_3x4fv (GstGLShader * shader,
  * @transpose: transpose the matrix
  * @value: values to set
  *
- * Perform `glUniformMatrix4x2fv()` for @name on @shader
+ * Perform glUniformMatrix4x2fv() for @name on @shader
  */
 void
 gst_gl_shader_set_uniform_matrix_4x2fv (GstGLShader * shader,
     const gchar * name, gint count, gboolean transpose, const gfloat * value)
 {
-  set_uniform_pre_check (shader, name);
-  shader->context->gl_vtable->UniformMatrix4x2fv (location, count, transpose,
-      value);
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->UniformMatrix4x2fv (location, count, transpose, value);
 }
 
 /**
@@ -1209,15 +1496,24 @@ gst_gl_shader_set_uniform_matrix_4x2fv (GstGLShader * shader,
  * @transpose: transpose the matrix
  * @value: values to set
  *
- * Perform `glUniformMatrix4x3fv()` for @name on @shader
+ * Perform glUniformMatrix4x3fv() for @name on @shader
  */
 void
 gst_gl_shader_set_uniform_matrix_4x3fv (GstGLShader * shader,
     const gchar * name, gint count, gboolean transpose, const gfloat * value)
 {
-  set_uniform_pre_check (shader, name);
-  shader->context->gl_vtable->UniformMatrix4x3fv (location, count, transpose,
-      value);
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+  GLint location = -1;
+
+  g_return_if_fail (shader != NULL);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
+
+  location = _get_uniform_location (shader, name);
+
+  gl->UniformMatrix4x3fv (location, count, transpose, value);
 }
 
 /**
@@ -1230,17 +1526,20 @@ gst_gl_shader_set_uniform_matrix_4x3fv (GstGLShader * shader,
 GLint
 gst_gl_shader_get_attribute_location (GstGLShader * shader, const gchar * name)
 {
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
   gint ret;
 
   g_return_val_if_fail (shader != NULL, -1);
-  g_return_val_if_fail (shader->priv->program_handle != 0, -1);
+  priv = shader->priv;
+  g_return_val_if_fail (priv->program_handle != 0, -1);
 
-  ret =
-      shader->context->gl_vtable->GetAttribLocation (shader->priv->
-      program_handle, name);
+  gl = shader->context->gl_vtable;
 
-  GST_TRACE_OBJECT (shader, "retrieved program %i attribute \'%s\' location %i",
-      (int) shader->priv->program_handle, name, ret);
+  ret = gl->GetAttribLocation (priv->program_handle, name);
+
+  GST_TRACE_OBJECT (shader, "retreived program %i attribute \'%s\' location %i",
+      (int) priv->program_handle, name, ret);
 
   return ret;
 }
@@ -1252,20 +1551,24 @@ gst_gl_shader_get_attribute_location (GstGLShader * shader, const gchar * name)
  * @name: name of the attribute
  *
  * Bind attribute @name to the specified location @index using
- * `glBindAttributeLocation()`.
+ * glBindAttributeLocation().
  */
 void
 gst_gl_shader_bind_attribute_location (GstGLShader * shader, GLuint index,
     const gchar * name)
 {
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+
   g_return_if_fail (shader != NULL);
-  g_return_if_fail (shader->priv->program_handle != 0);
+  priv = shader->priv;
+  g_return_if_fail (priv->program_handle != 0);
+  gl = shader->context->gl_vtable;
 
   GST_TRACE_OBJECT (shader, "binding program %i attribute \'%s\' location %i",
-      (int) shader->priv->program_handle, name, index);
+      (int) priv->program_handle, name, index);
 
-  shader->context->gl_vtable->BindAttribLocation (shader->priv->program_handle,
-      index, name);
+  gl->BindAttribLocation (priv->program_handle, index, name);
 }
 
 /**
@@ -1275,20 +1578,24 @@ gst_gl_shader_bind_attribute_location (GstGLShader * shader, GLuint index,
  * @name: name of the attribute
  *
  * Bind attribute @name to the specified location @index using
- * `glBindFragDataLocation()`.
+ * glBindFragDataLocation().
  */
 void
 gst_gl_shader_bind_frag_data_location (GstGLShader * shader,
     guint index, const gchar * name)
 {
+  GstGLShaderPrivate *priv;
+  GstGLFuncs *gl;
+
   g_return_if_fail (shader != NULL);
   if (!_ensure_program (shader))
     g_return_if_fail (shader->priv->program_handle);
-  g_return_if_fail (shader->context->gl_vtable->BindFragDataLocation);
+  priv = shader->priv;
+  gl = shader->context->gl_vtable;
+  g_return_if_fail (gl->BindFragDataLocation);
 
   GST_TRACE_OBJECT (shader, "binding program %i frag data \'%s\' location %i",
-      (int) shader->priv->program_handle, name, index);
+      (int) priv->program_handle, name, index);
 
-  shader->context->gl_vtable->BindFragDataLocation (shader->priv->
-      program_handle, index, name);
+  gl->BindFragDataLocation (priv->program_handle, index, name);
 }
